#ifndef SYSINC_H
#define SYSINC_H
/*
  System includes for Xlogmaster
*/

#include <X11/Xlib.h>
#include <X11/Xresource.h>
#include <gtk/gtk.h>

#include <sys/stat.h>
#include <sys/types.h>
#include <sys/wait.h>

#if HAVE_SYS_MMAN_H
#include <sys/mman.h>
#endif /* HAVE_SYS_MMAN_H */

#include <stdio.h>
#include <stdlib.h>
#include <fcntl.h>
#include <fstream.h>
#include <strstream.h>
#include <unistd.h>
#include <string.h>
#include <time.h>
#include <errno.h>

#endif /* SYSINC_H */
